var ace = require('brace');
require('brace/ext/statusbar');
var StatusBar = ace.acequire('ace/ext/statusbar').StatusBar;

module.exports = {
  template: '<div :style="{width: width, position: position, top: top, bottom: bottom}"></div>',

  props: {
    content: {
      type: String,
      required: true
    },
    position: {
      type: String,
      default: 'absolute'
    },
    top: {
      type: String,
      default: '35px',
    },
    bottom: {
      type: String,
      default: '0',
    },
    lang: {
      type: String,
      default: 'javascript'
    },
    theme: {
      type: String,
      default: 'chrome'
    },
    width: {
      type: String,
      default: '100%'
    },
    sync: {
      type: Boolean,
      default: false
    },
    options: {
      type: Object,
      default: function () { return {}; }
    }
  },

  data: function () {
    return {
      editor: null,
    };
  },

  mounted: function () {
    var vm = this;
    var lang = vm.lang;
    var theme = vm.theme;
    var editor = vm.editor = ace.edit(vm.$el);
    var options = vm.options;
    editor.$blockScrolling = Infinity;
    editor.getSession().setMode('ace/mode/' + lang);
    editor.setTheme('ace/theme/' + theme);
    editor.setValue(vm.content, 1);
    editor.setOptions(options);
    editor.on('change', function () {
      vm.$parent.$emit('editor-update', editor.getValue());
    });

//    var statusBar = new StatusBar(editor, document.getElementById('statusBar'));
  },

  watch: {
    content: function (newContent) {
      var vm = this;
      if (vm.sync) {
        vm.editor.setValue(newContent, 1);
      }
    },

    theme: function (newTheme) {
      var vm = this;
      vm.editor.setTheme('ace/theme/' + newTheme);
    },

    lang: function(newLang) {
      var vm = this;
      vm.editor.getSession().setMode('ace/mode/' + newLang);
    }
  }
};
